col.z: Color scale for a specified quantile. This scale is intended...

Description Usage Arguments Value

View source: R/hmfns.R

Description

Color scale for a specified quantile. This scale is intended for heatmaps containing negative and positive values, so the range is set to c(quant,1-quant).

Usage

1
col.z(x, quant = 0.01)

Arguments

x

A numeric matrix or vector.

quant

The quantile to be used as the scale limits.

Value

A colorRamp2 scale which can be passed to Heatmap().


kewiechecki/atacSeqFns documentation built on Sept. 27, 2020, 8:25 a.m.