cond.col.vec: Creates a color scale for the levels in a vector, then...

Description Usage Arguments Value

View source: R/hmfns.R

Description

Creates a color scale for the levels in a vector, then returns a vector assigning a color to each element of the input vector.

Usage

1
cond.col.vec(cond, colfn = rainbow, ...)

Arguments

cond

A vector that can be coerced to a factor.

colfn

A function that returns a color map for each level in cond.

...

Additional arguments to colfn.

Value

A vector of colors corresponding to the elements of cond.


kewiechecki/atacSeqFns documentation built on Sept. 27, 2020, 8:25 a.m.