lrtab: Applies a function to all file names in a specified directory...

Description Usage Arguments Value See Also Examples

View source: R/dirfns.R

Description

Applies a function to all file names in a specified directory matching a given pattern.

Usage

1

Arguments

dir

The traget directory.

fn

The function to be applied to each directory name.

pattern

The regular expression matching desired files.

...

Additional arguments to fn.

Value

A list.

See Also

dir.img, base::list.files

Examples

1
2
3
dir.csv(iris, "example", path="path/to")
dir.tab(iris, "example", path="path/to")
lrtab("path/to", read.csv, "\\.csv")

kewiechecki/atacSeqFns documentation built on Sept. 27, 2020, 8:25 a.m.