Description Usage Arguments Value
Color scale for a specified quantile. This scale is intended for heatmaps containing negative and positive values, so the range is set to c(quant,1-quant).
1 | col.z(x, quant = 0.01)
|
x |
A numeric matrix or vector. |
quant |
The quantile to be used as the scale limits. |
A colorRamp2 scale which can be passed to Heatmap().
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.