Description Usage Arguments Value See Also Examples
Applies a function to all file names in a specified directory matching a given pattern.
1 |
dir |
The traget directory. |
fn |
The function to be applied to each directory name. |
pattern |
The regular expression matching desired files. |
... |
Additional arguments to |
A list.
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.